import warnings

from cli_base.cli_tools.git import Git as NewGit
from cli_base.cli_tools.git import (  # noqa
    GitBinNotFoundError,
    GitError,
    GitTagInfo,
    GitTagInfos,
    NoGitRepoError,
    get_git_root,
)


class Git(NewGit):
    """
    DEPRECATED: Migrate to: cli_base.cli_tools.git.Git
    """

    def __init__(self, *args, **kwargs):
        warnings.warn(
            'Migrate to: cli_base.cli_tools.git.Git !',
            DeprecationWarning,
            stacklevel=2,
        )
        super().__init__(*args, **kwargs)



import warnings

from cli_base.cli_tools.version_info import print_version as new_print_version


def print_version(*args, **kwargs) -> None:
    """
    DEPRECATED: Migrate to: cli_base.cli_tools.version_info.print_version !
    """
    warnings.warn(
        'Migrate to: cli_base.cli_tools.version_info.print_version !',
        DeprecationWarning,
        stacklevel=2,
    )
    new_print_version(*args, **kwargs)



import warnings

from cli_base.cli_tools.test_utils.git_utils import init_git as new_init_git


def init_git2(*args, **kwargs):
    """
    DEPRECATED: Migrate to: cli_base.cli_tools.test_utils.git_utils.init_git !
    """
    warnings.warn(
        'Migrate to: cli_base.cli_tools.test_utils.git_utils.init_git !',
        DeprecationWarning,
        stacklevel=2,
    )
    new_init_git(*args, **kwargs)
